import { createApp } from 'vue';
import App from './App.vue';

import PrimeVue from 'primevue/config';
import Dialog from 'primevue/dialog';
import Button from 'primevue/button';
import InputText from 'primevue/inputtext';
import Menubar from 'primevue/menubar';
import Panel from 'primevue/panel';
import Card from 'primevue/card';
import Listbox from 'primevue/listbox';
import ProgressBar from 'primevue/progressbar';
import Message from 'primevue/message';
import Chip from 'primevue/chip';
import Dropdown from 'primevue/dropdown';
import ToastService from 'primevue/toastservice';
import Toast from 'primevue/toast';
// import Tooltip from 'primevue/tooltip';
import ScrollPanel from 'primevue/scrollpanel';
import OverlayPanel from 'primevue/overlaypanel';
import Sidebar from 'primevue/sidebar';
import OrganizationChart from 'primevue/organizationchart';
import Navbar from './layout/navbar.vue'
import Fieldset from 'primevue/fieldset';
import TieredMenu from "primevue/tieredmenu";

import TabView from 'primevue/tabview';
import TabPanel from 'primevue/tabpanel';
import Divider from 'primevue/divider';
import Tag from 'primevue/tag';
import Avatar from 'primevue/avatar';
import AvatarGroup from 'primevue/avatargroup';
import ColorPicker from 'primevue/colorpicker';
import Calendar from 'primevue/calendar';
import DataTable from 'primevue/datatable';
import Column from 'primevue/column';
import ColumnGroup from 'primevue/columngroup';
import Checkbox from 'primevue/checkbox';
import Textarea from 'primevue/textarea';
import RadioButton from 'primevue/radiobutton';
import Badge from 'primevue/badge';
import ProgressSpinner from 'primevue/progressspinner';
import OrderList from "primevue/orderlist";
import FileUpload from 'primevue/fileupload';
import InputMask from 'primevue/inputmask';
import InputNumber from 'primevue/inputnumber';
import MultiSelect from 'primevue/multiselect';
import Menu from 'primevue/menu';

import ScrollTop from 'primevue/scrolltop';
import Skeleton from 'primevue/skeleton';
import Chart from 'primevue/chart';
import Breadcrumb from 'primevue/breadcrumb';
import Timeline from 'primevue/timeline';
import Editor from 'primevue/editor';

import 'primevue/resources/themes/mdc-light-indigo/theme.css';
import 'primevue/resources/primevue.min.css';
import 'primeicons/primeicons.css';
import 'primeflex/primeflex.css';

import router from './router'

import { auth } from './db';
import { store } from './store/store'


import { Pie, Bar } from "vue-chartjs";
import {
    Chart as ChartJS,
    Title,
    Tooltip,
    Legend,
    BarElement,
    CategoryScale,
    LinearScale,
    ArcElement
} from "chart.js";

ChartJS.register(Title, Legend, BarElement, CategoryScale, LinearScale, ArcElement, Tooltip);



import { getSession } from "./services/session";
import { setupInterceptorsAxiosMicrosoftGraph, setupInterceptorsAxiosResponseMicrosoftGraph } from './services/setupInterceptorsAxiosMicrosoftGraph';
setupInterceptorsAxiosMicrosoftGraph(getSession()?.token);
setupInterceptorsAxiosResponseMicrosoftGraph()


import VueAxios from 'vue-axios'
import axios from 'axios'


let app: any = null;
//Esta envuelto en onAuthStateChanged es para cargar lo correspondiente a vue una vez el sdk de firebase este inicializado
auth.onAuthStateChanged(async (user) => {
    if (!app) {
        app = createApp(App);
        app.use(PrimeVue);
        app.component('Dialog', Dialog);
        app.component('Button', Button);
        app.component('InputText', InputText);
        app.component('Menubar', Menubar);
        app.component('Panel', Panel);
        app.component('Card', Card);
        app.component('ProgressBar', ProgressBar)
        app.component('Message', Message)
        app.component('Chip', Chip)
        app.component('Navbar', Navbar)
        app.component('Listbox', Listbox);
        app.component('Dropdown', Dropdown);
        app.component('OrganizationChart', OrganizationChart);
        app.use(ToastService);
        app.component('Toast', Toast);
        app.component('ScrollPanel', ScrollPanel);
        // app.directive('tooltip', Tooltip);
        app.component('OverlayPanel', OverlayPanel);
        app.component('Sidebar', Sidebar);
        app.component('Fieldset', Fieldset);
        app.component('TieredMenu', TieredMenu);
        app.component('TabView', TabView);
        app.component('TabPanel', TabPanel);
        app.component('Divider', Divider);
        app.component('Tag', Tag);
        app.component('Avatar', Avatar);
        app.component('AvatarGroup', AvatarGroup);
        app.component('DataTable', DataTable);
        app.component('Column', Column);
        app.component('ColumnGroup', ColumnGroup);
        app.component('Checkbox', Checkbox);
        app.component('ColorPicker', ColorPicker);
        app.component('OrderList', OrderList);
        app.component('Textarea', Textarea);
        app.component('RadioButton', RadioButton);
        app.component('Badge', Badge);
        app.component('ProgressSpinner', ProgressSpinner);
        app.component('Calendar', Calendar);
        app.component('FileUpload', FileUpload);
        app.component('InputMask', InputMask);
        app.component('InputNumber', InputNumber);
        app.component('MultiSelect', MultiSelect);
        app.component('Chart', Chart);
        app.component('ScrollTop', ScrollTop);
        app.component('Skeleton', Skeleton);
        app.component('Menu', Menu);
        app.component('Breadcrumb', Breadcrumb);
        app.component('Timeline', Timeline);
        app.component('Editor', Editor);

        app.component('Pie', Pie);
        app.component('Bar', Bar);



        app.use(store)
        app.use(router)
        app.use(VueAxios, { $axios: axios })
        app.mount('#app')

    }
});

