import { createWebHistory, createRouter } from "vue-router";
import Login from "./pages/login.vue";
// import Home from "./pages/Home.vue";

import Meetings from "./pages/meetings/meetings.vue";
import MeetingDetail from "./pages/meetings/meeting-detail.vue";


import Teams from "./pages/teams/teams.vue";
import LiveChannels from "./pages/teams/live-channels.vue";
import ChannelMeetingHistory from "./pages/teams/channel-meeting-history.vue";
import TeamStudents from "./pages/teams/team-students.vue";
import Student from "./pages/reports/student.vue";
import StudentLogin from "./pages/reports/studentLogin.vue";
import Users from "./pages/admin/users.vue";
import UserStudentLists from "./pages/admin/user-student-lists.vue";
import UserStudents from "./pages/admin/user-students.vue";

import ControlFictionalMeeting from "./pages/admin/control-fictional-meeting.vue";
const routes = [
    {//Para el reporte del estudiante
        path: "/studentLogin/:rTypeReport/:rTeamId/:rChannelId/:rMeetingId/:rMMeetingId/:rMRoomId",
        name: "StudentLogin",
        component: StudentLogin
    },
    {
        path: "/login",
        name: "Login",
        component: Login
    },
    {
        path: "/",
        name: "Meetings",
        component: Meetings, meta: {
            authRequired: true,
        },
    },
    {
        path: "/teams",
        name: "Teams",
        component: Teams, meta: {
            authRequired: true,
        },
    },
    {
        path: "/channel/:teamId/:teamName/:teacherEmail/:teacherName",
        name: "Channels",
        component: LiveChannels, meta: {
            authRequired: true,
        },
    },
    {
        path: "/team-students/:teamId/:teamName",
        name: "TeamStudents",
        component: TeamStudents, meta: {
            authRequired: true,
        },
    },
    {
        path: "/meeting-detail/:teacherId/:teacherEmail/:teacherName/:meetingId/:meetingName",
        name: "MeetingDetail",
        component: MeetingDetail, meta: {
            authRequired: true,
        },
    },
    {
        path: '/channel-meeting-history-detail/:teamId/:teamName/:teacherEmail/:teacherName', component: ChannelMeetingHistory, meta: {
            authRequired: true,
        },
    },
    {
        path: '/admin-users', component: Users, meta: {
            authRequired: true,
        },
    },

    {
        path: "/admin-meetings/:userId/:userEmail/:userName",
        name: "AdminMeetings",
        component: Meetings, meta: {
            authRequired: true,
        },
    },
    {
        path: "/admin-teams/:userId/:teacherEmail/:teacherName",
        name: "AdminTeams",
        component: Teams, meta: {
            authRequired: true,
        },
    },
    {
        path: "/user-student-lists/:adminUserId/:adminUserName",
        name: "AdminUserStudentLists",
        component: UserStudentLists, meta: {
            authRequired: true,
        },
    },

    {
        path: "/user-students/:adminUserId/:adminUserName/:adminListId",
        name: "AdminUserStudents",
        component: UserStudents, meta: {
            authRequired: true,
        },
    },
    {
        path: "/control-fictional-meeting/:adminUserId/:adminUserName",
        name: "AdminControlFictionalMeeting",
        component: ControlFictionalMeeting, meta: {
            authRequired: true,
        },
    },
    {//Para el reporte del estudiante
        path: '/report/:rTeamId/:rChannelId/:rMeetingId',
        name: "TeamsReport",
        component: Student, meta: {
            authRequired: false,
        },
    },
    {//Para el reporte del estudiante
        path: '/student-meeting-report/:rMMeetingId/:rMRoomId',
        name: "MeetingReport",
        component: Student, meta: {
            authRequired: false,
        },
    }
]

const router = createRouter({
    history: createWebHistory(),
    routes,
});

import { auth } from './db';

router.beforeEach(async (to, from, next) => {
    if (to.matched.some(record => record.meta.authRequired)) {
        if (auth.currentUser) {
            next();
        } else {
            next({ path: `/login` });
        }
    } else {
        next();
    }
});
export default router;

