import firebase from "firebase/app";
import { db, auth } from "../db";
import moment from "moment";
import { setSession } from "./session";
import { setupInterceptorsAxiosMicrosoftGraph } from "./setupInterceptorsAxiosMicrosoftGraph";

export const googleSignInWithPopup = async () => {

  let provider = new firebase.auth.GoogleAuthProvider();
  let result = await auth.signInWithPopup(provider);
  let user = await getUserFromGoogle(result)
  await userInsert(user.id, user.name, user.email)
  setSession(user);
  return user
}

export const microsoftSignInWithPopup = async () => {

  var provider = new firebase.auth.OAuthProvider("microsoft.com");

  // provider.addScope("Team.ReadBasic.All");
  // provider.addScope("Channel.ReadBasic.All");

  provider.setCustomParameters({
    // Force re-consent.
    prompt: "consent",
    // Target specific email with login hint.
    // login_hint: "user@firstadd.onmicrosoft.com",
  });

  let result = await auth.signInWithPopup(provider);

  let user = await getUserFromMicrosoft(result)
  await userInsert(user.id, user.name, user.email)
  setupInterceptorsAxiosMicrosoftGraph(user.token);
  setSession(user);

  return user
}

export const reauthenticateWithPopup = async () => {
  var provider = new firebase.auth.OAuthProvider("microsoft.com");
  let result = await auth.currentUser?.reauthenticateWithPopup(provider)
  let user = await getUserFromMicrosoft(result)
  setSession(user);
  return user.token
}


const userInsert = async (userId: string, name: string, email: string) => {

  let user = await db.ref(`users/${userId}`).once(`value`);
  if (!user.exists()) {
    await db.ref(`users/${userId}`).update({
      createdAt: moment().format(),
      name: name,
      email: email
    });

  }
  let userInfo = await db.ref(`users_info/${userId}`).once(`value`);
  if (!userInfo.exists())
    await db.ref(`users_info/${userId}`).update({
      createdAt: moment().format(),
      name: name,
      email: email
    });






  // let usersResult = await db
  //   .ref(`users`)
  //   .orderByChild("email")
  //   .equalTo("benito.auria@cti.espol.edu.ec")
  //   .limitToLast(1)
  //   .once(`value`);



}

const getUserFromMicrosoft = async (result: any) => {
  let userId = result.additionalUserInfo.profile.id
  let user = {
    name: result.additionalUserInfo.profile.displayName,
    email: result.additionalUserInfo.profile.mail,
    token: result.credential.accessToken,
    expiresAt: moment().format(),
    id: userId.replaceAll("-", "")
  };
  return user
}


const getUserFromGoogle = async (result: any) => {


  let userId = result.additionalUserInfo.profile.id
  let user = {
    name: result.additionalUserInfo.profile.name,
    email: result.additionalUserInfo.profile.email,
    token: result.credential.accessToken,
    expiresAt: moment().format(),
    id: userId.replaceAll("-", "")
  };
  return user

}