import { mGraphApi } from "./axiosInstanceForMicrosoftGraph";
import { reauthenticateWithPopup } from "./authProvider";

let isRefreshing = false;
let currentToken = ""
export const setupInterceptorsAxiosMicrosoftGraph = (token: string = "") => {
    if (token != "") {
        currentToken = token
        mGraphApi.interceptors.request.use(
            (config: any) => {
                isRefreshing = false;
                config.headers["Authorization"] = 'Bearer ' + currentToken
                return config;
            },
            (error: any) => {
                return Promise.reject(error);
            }
        );
    }
};

export const setupInterceptorsAxiosResponseMicrosoftGraph = () => {
    mGraphApi.interceptors.response.use(
        (res) => {
            return res;
        },
        async (err) => {
            const originalConfig = err.config;
            if (err.response) {
             
                
                if (err.response.status === 401 && !isRefreshing) {
                    isRefreshing = true;
                    try {
                        currentToken = await reauthenticateWithPopup()
                        mGraphApi.defaults.headers.common["Authorization"] = 'Bearer ' + currentToken
                        isRefreshing = false;
                        return mGraphApi(originalConfig);
                    } catch (_error: any) {
                        if (_error.response && _error.response.data) {
                            return Promise.reject(_error.response.data);
                        }
                        return Promise.reject(_error);
                    }
                }
                if (err.response.status === 403 && err.response.data) {
                    return Promise.reject(err.response.data);
                }
            }
            return Promise.reject(err);
        }
    );
};